pattern property
Substring matched against an import line to assign it to this tier.
For example package:ptp_shared groups all imports from that package.
Implementation
final String pattern;
Substring matched against an import line to assign it to this tier.
For example package:ptp_shared groups all imports from that package.
final String pattern;