removeUnused property
Whether dart fix --apply --code=unused_import runs before sorting.
Opt-in for the same reason, and because it costs an analyzer pass.
Implementation
final bool removeUnused;
Whether dart fix --apply --code=unused_import runs before sorting.
Opt-in for the same reason, and because it costs an analyzer pass.
final bool removeUnused;