duplicatesRemoved property
How many directives removeDuplicates dropped. Always 0 when the option
is off, so a caller can report it without checking the flag.
Implementation
final int duplicatesRemoved;
How many directives removeDuplicates dropped. Always 0 when the option
is off, so a caller can report it without checking the flag.
final int duplicatesRemoved;