CustomTier class
A user-defined import tier that sits between generic package: imports
and project imports. See issue import_sorter#81.
Constructors
- CustomTier(String name, String pattern)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The comment label written above the group (without a leading
//).final - pattern → String
-
Substring matched against an import line to assign it to this tier.
For example
package:ptp_sharedgroups all imports from that package.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited